@@ -54,16 +54,6 @@ from rpy2.rinterface import (NA_Real,
                              NA_Complex, 
                              NULL)
 
-if sys.version_info[0] == 2:
-    py3str = unicode
-    py3bytes = str
-    import itertools
-    zip = itertools.izip
-else:
-    long = int
-    py3str = str
-    py3bytes = bytes
-
 _rparse = rinterface.baseenv['parse']
 _reval = rinterface.baseenv['eval']
 
@@ -131,6 +121,7 @@ TYPEORDER = {bool: (0, BoolVector),
              str: (4, StrVector)}
 def sequence_to_vector(lst):
     curr_typeorder = -1
+    i = None
     for i, elt in enumerate(lst):
         cls = type(elt)
         if cls in TYPEORDER:
@@ -138,6 +129,8 @@ def sequence_to_vector(lst):
                 curr_typeorder, curr_type = TYPEORDER[cls]
         else:
             raise ValueError('The element %i in the list has a type that cannot be handled.' % i)
+    if i is None:
+        raise ValueError('The parameter "lst" is an empty sequence. The type of the corresponding R vector cannot be determined.')
     res = curr_type(lst)
     return res
 
@@ -208,17 +201,16 @@ def int2ri(obj):
     return res
 
 default_converter.py2ri.register(int, int2ri)
-default_converter.py2ri.register(long, int2ri)
 
 @default_converter.py2ri.register(float)
 def _(obj):
     return rinterface.SexpVector([obj, ], rinterface.REALSXP)
 
-@default_converter.py2ri.register(py3bytes)
+@default_converter.py2ri.register(bytes)
 def _(obj):
     return rinterface.SexpVector([obj, ], rinterface.STRSXP)
 
-@default_converter.py2ri.register(py3str)
+@default_converter.py2ri.register(str)
 def _(obj):
     return rinterface.SexpVector([obj, ], rinterface.STRSXP)
 
@@ -236,6 +228,7 @@ def _(obj):
 def _(obj):
     return rinterface.SexpVector([obj, ], rinterface.CPLXSXP)
 
+
 @default_converter.py2ro.register(object)
 def _(obj):
     robj = conversion.py2ri(obj)
